// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/component_copy_with_extension.dart';
import 'package:wyatt_ui_components/src/core/mixins/copy_with_mixin.dart';
import 'package:wyatt_ui_components/src/domain/entities/cards/card_component.dart';

part 'quote_card_component.g.dart';

@ComponentProxyExtension()
abstract class QuoteCardComponent extends CardComponent
    with CopyWithMixin<$QuoteCardComponentCWProxy> {
  const QuoteCardComponent({
    required this.avatar,
    required this.name,
    required this.subtitle,
    required this.gradient,
    required this.quote,
    this.leftQuote,
    this.rightQuote,
    super.radius = 12,
    super.padding = 25,
    super.borderColors = const [Color(0xFFDDE0E3), Color(0xFFCACCD4)],
    super.backgroundColor = const Color(0xFFF6F6F6),
    super.minSize = const Size(330, 230),
    super.maxSize = const Size(330, 530),
    super.shadow = const BoxShadow(
      blurRadius: 30,
      offset: Offset(0, 5),
      color: Color.fromRGBO(0, 0, 0, 0.05),
    ),
    super.background,
    super.key,
  });

  final Widget avatar;
  final Widget name;
  final Text subtitle;
  final Gradient gradient;
  final Widget quote;

  final Widget? leftQuote;
  final Widget? rightQuote;
}
